@@ -439,12 +439,20 @@ class SQL(BaseSQLDialect):
             col_quoted = th.resolve_references(
                 col, options={"alias_column": False, "alias_table": False}
             )
+            is_special = isinstance(val, str) and val.startswith("@@") and val[2:]
             if excluded:
-                # For ON CONFLICT DO UPDATE statements, use the EXCLUDED value
-                set_clauses.append(f"{col_quoted} = EXCLUDED.{col_quoted}")
+                if is_special:
+                    # Allow callers to force literal expressions like CURRENT_TIMESTAMP
+                    set_clauses.append(f"{col_quoted} = {val[2:]}")
+                else:
+                    # For ON CONFLICT DO UPDATE statements, use the EXCLUDED value
+                    set_clauses.append(f"{col_quoted} = EXCLUDED.{col_quoted}")
             else:
-                set_clauses.append(f"{col_quoted} = %s")
-                vals.append(val)
+                if is_special:
+                    set_clauses.append(f"{col_quoted} = {val[2:]}")
+                else:
+                    set_clauses.append(f"{col_quoted} = %s")
+                    vals.append(val)
 
         # Build WHERE clauses for a normal update (ignored when excluded is True)
         where_clauses = []
@@ -836,6 +844,16 @@ class SQL(BaseSQLDialect):
               COST 100;
         """
 
+    @staticmethod
+    def _sys_keywords_index_name(schema_unquoted, table_unquoted):
+        base_index_name = f"idx_{schema_unquoted}_{table_unquoted}_sys_keywords_tsv"
+        base_index_name = re.sub(r"[^0-9a-zA-Z_]+", "_", base_index_name)
+        if len(base_index_name) > 60:
+            digest = hashlib.sha256(base_index_name.encode("utf-8")).hexdigest()
+            base_index_name = f"idx_{table_unquoted[:30]}_{digest[:8]}_sk"
+            base_index_name = re.sub(r"[^0-9a-zA-Z_]+", "_", base_index_name)
+        return base_index_name[:63]
+
     @classmethod
     def create_table(cls, name, columns={}, drop=False):
         if "." in name:
@@ -865,7 +883,7 @@ class SQL(BaseSQLDialect):
               sys_modified_count INTEGER NOT NULL DEFAULT 0,
               sys_dirty BOOLEAN NOT NULL DEFAULT FALSE,
               sys_table TEXT NOT NULL,
-                            sys_keywords TEXT
+              sys_keywords TEXT
             );
 
             SELECT SETVAL(PG_GET_SERIAL_SEQUENCE('{fqtn}', 'sys_id'),1000,TRUE);
@@ -889,6 +907,12 @@ class SQL(BaseSQLDialect):
                 f"ALTER TABLE {TableHelper.quote(fqtn)} ADD COLUMN {TableHelper.quote(key)} {TYPES.get_type(val)};"
             )
 
+        index_name = cls._sys_keywords_index_name(schema_unquoted, table_unquoted)
+        index_identifier = TableHelper.quote(index_name)
+        sql.append(
+            f"CREATE INDEX {index_identifier} ON {fqtn} USING GIN (TO_TSVECTOR('simple', COALESCE(sys_keywords, '')));"
+        )
+
         sql = sqlparse.format(" ".join(sql), reindent=True, keyword_case="upper")
         return sql, tuple()
 
@@ -1035,18 +1059,17 @@ class SQL(BaseSQLDialect):
             )
 
         if "sys_keywords" in columns_after:
-            base_index_name = f"idx_{schema_unquoted}_{table_unquoted}_sys_keywords_tsv"
-            base_index_name = re.sub(r"[^0-9a-zA-Z_]+", "_", base_index_name)
-            if len(base_index_name) > 60:
-                digest = hashlib.sha256(base_index_name.encode("utf-8")).hexdigest()
-                base_index_name = f"idx_{table_unquoted[:30]}_{digest[:8]}_sk"
-                base_index_name = re.sub(r"[^0-9a-zA-Z_]+", "_", base_index_name)
-            index_name = base_index_name[:63]
+            index_name = cls._sys_keywords_index_name(schema_unquoted, table_unquoted)
             quoted_index_name = TableHelper.quote(index_name)
 
-            target_expression = "to_tsvector('simple', coalesce(sys_keywords, ''))"
-            current_definition = existing_indexes.get(index_name.lower(), "").lower()
-            needs_rebuild = force or target_expression not in current_definition
+            current_definition = existing_indexes.get(index_name.lower(), "")
+            current_definition_lower = current_definition.lower()
+            has_target = (
+                "to_tsvector" in current_definition_lower
+                and "coalesce" in current_definition_lower
+                and "sys_keywords" in current_definition_lower
+            )
+            needs_rebuild = force or not has_target
 
             if needs_rebuild:
                 statements.append(
